pub struct GitIndex { /* private fields */ }Expand description
Snapshot of git status for paths under a repository root.
Implementations
Sourceimpl GitIndex
impl GitIndex
pub fn empty() -> Self
pub fn repo_root(&self) -> Option<&Path>
pub fn status_for(&self, path: &Path) -> GitStatus
Sourcepub fn discover(start: &Path) -> Self
pub fn discover(start: &Path) -> Self
Discover repo from start and load porcelain status (cached).
Sourcepub fn discover_with(start: &Path, untracked: UntrackedMode) -> Self
pub fn discover_with(start: &Path, untracked: UntrackedMode) -> Self
Discover with untracked policy (uses process-wide cache).