Crate f00_git

Crate f00_git 

Optional git status integration for f00.

Uses git status --porcelain as a lightweight subprocess MVP (no libgit2).

Structs

GitIndex
Snapshot of git status for paths under a repository root.

Functions

annotate_entries
Convenience: annotate a free list of entries using a starting path for discovery.
annotate_listing
Annotate listing entries with git status in place.
annotate_listings
Annotate many listings; one porcelain map per git repo root (reused).
find_repo_root
Walk up from start looking for a .git directory/file.