Optional git status integration for f00.
Uses git status --porcelain as a lightweight subprocess MVP (no libgit2).
Structs
- GitIndex
- Snapshot of git status for paths under a repository root.
Functions
- annotate_
entries - Convenience: annotate a free list of entries using a starting path for discovery.
- annotate_
listing - Annotate listing entries with git status in place.
- annotate_
listings - Annotate many listings; one porcelain map per git repo root (reused).
- find_
repo_ root - Walk up from
startlooking for a.gitdirectory/file.